@@ -4,7 +4,9 @@ if (class(stratum)[1]!="optmatch" & is.null(trtgrp))
   stop("stratum not of class \'optmatch\'; trtgrp must be specified")
 if (class(stratum)[1]!="optmatch")
   warning("stratum not of class optmatch; was this intended?")
-if (class(stratum)[1]=="optmatch" & !is.null(trtgrp))
+if (class(stratum)[1]=="optmatch" & is.null(attr(stratum, "contrast.group")) & is.null(trtgrp))
+  stop("Argument 1 is of class optmatch but it has lost its contrast.group attribute; must specify trtgrp")
+if (class(stratum)[1]=="optmatch" & !is.null(attr(stratum, "contrast.group")) & !is.null(trtgrp))
   warning("ignoring second argument to stratumStructure")
 if (class(stratum)[1]=="optmatch")
    {
